==> dart_blocks-0.0.9.tar.gz: lib/user_client/user_client.dart <==
import 'package:dart_blocks/softcorp_authorize/softcorp_authorize.dart';
import 'package:dart_softcorp_blocks/block_user.pbgrpc.dart';

class UserClient {
  // _grpcUserClient is an object to communicate with the server
  late final UserServiceClient _grpcUserClient;
  late final String? _encryptionKey;
  late final Authorize _authorize;

  UserClient({
    required UserServiceClient grpcUserClient,
    required Authorize authorize,
    String? encryptionKey,
  }) {
    _grpcUserClient = grpcUserClient;
    _authorize = authorize;
    _encryptionKey = encryptionKey ?? "";
  }

  Future<User> create({
    String? userId,
    String? optionalId,
    String? email,
    String? image,
    String? password,
    bool? validatePassword,
  }) async {
    print("get here 0");
    String accessToken = await _authorize.getAccessToken();
    print("get here 1");
    UserRequest req = UserRequest();
    User user = User();
    print("get here 2");
    user.id = userId ?? "";
    print("get here 3");
    user.optionalId = optionalId ?? "";
    print("get here 4");
    user.email = email ?? "";
    print("get here 5");
    user.image = image ?? "";
    print("get here 6");
    user.password = password ?? "";
    print("get here 7");
    req.validatePassword = validatePassword ?? false;
    print("get here 8");
    req.cloudToken = accessToken;
    print("get here 9");
    req.encryptionKey = _encryptionKey ?? "";
    print("get here 10");
    try {
      UserResponse resp  = await _grpcUserClient.create(req);
      return resp.user;
    } catch(e){
      print("could not create user");
      rethrow;
    }
  }
}

==> dart_blocks-0.0.10.tar.gz: lib/user_client/user_client.dart <==
import 'package:dart_blocks/softcorp_authorize/softcorp_authorize.dart';
import 'package:dart_softcorp_blocks/block_user.pbgrpc.dart';

class UserClient {
  // _grpcUserClient is an object to communicate with the server
  late final UserServiceClient _grpcUserClient;
  late final String? _encryptionKey;
  late final Authorize _authorize;

  UserClient({
    required UserServiceClient grpcUserClient,
    required Authorize authorize,
    String? encryptionKey,
  }) {
    _grpcUserClient = grpcUserClient;
    _authorize = authorize;
    _encryptionKey = encryptionKey;
  }

  Future<User> create({
    String? userId,
    String? optionalId,
    String? email,
    String? image,
    String? password,
    bool? validatePassword,
  }) async {
    print("get here 0");
    print(_authorize);
    String accessToken = await _authorize.getAccessToken();
    print("get here 1");
    UserRequest req = UserRequest();
    User user = User();
    print("get here 2");
    user.id = userId ?? "";
    print("get here 3");
    user.optionalId = optionalId ?? "";
    print("get here 4");
    user.email = email ?? "";
    print("get here 5");
    user.image = image ?? "";
    print("get here 6");
    user.password = password ?? "";
    print("get here 7");
    req.validatePassword = validatePassword ?? false;
    print("get here 8");
    req.cloudToken = accessToken;
    print("get here 9");
    req.encryptionKey = _encryptionKey ?? "";
    print("get here 10");
    try {
      UserResponse resp  = await _grpcUserClient.create(req);
      return resp.user;
    } catch(e){
      print("could not create user");
      rethrow;
    }
  }
}
